==> eam-wshub-proxyclient-11.6-0-sources.jar: net/datastream/schemas/mp_fields/FUELBLEND_Type.java <==

package net.datastream.schemas.mp_fields;

import javax.xml.bind.annotation.XmlAccessType;
import javax.xml.bind.annotation.XmlAccessorType;
import javax.xml.bind.annotation.XmlElement;
import javax.xml.bind.annotation.XmlType;
import org.openapplications.oagis_segments.QUANTITY;


/**
 * <p>Classe Java pour FUELBLEND_Type complex type.
 * 
 * <p>Le fragment de schéma suivant indique le contenu attendu figurant dans cette classe.
 * 
 * <pre>
 * &lt;complexType name="FUELBLEND_Type">
 *   &lt;complexContent>
 *     &lt;restriction base="{http://www.w3.org/2001/XMLSchema}anyType">
 *       &lt;sequence>
 *         &lt;element ref="{http://schemas.datastream.net/MP_fields}FUELCODE"/>
 *         &lt;element ref="{http://schemas.datastream.net/MP_fields}BLENDPERC"/>
 *       &lt;/sequence>
 *     &lt;/restriction>
 *   &lt;/complexContent>
 * &lt;/complexType>
 * </pre>
 * 
 * 
 */
@XmlAccessorType(XmlAccessType.FIELD)
@XmlType(name = "FUELBLEND_Type", propOrder = {
    "fuelcode",
    "blendperc"
})
public class FUELBLEND_Type {

    @XmlElement(name = "FUELCODE", required = true)
    protected String fuelcode;
    @XmlElement(name = "BLENDPERC", required = true)
    protected QUANTITY blendperc;

    /**
     * Obtient la valeur de la propriété fuelcode.
     * 
     * @return
     *     possible object is
     *     {@link String }
     *     
     */
    public String getFUELCODE() {
        return fuelcode;
    }

    /**
     * Définit la valeur de la propriété fuelcode.
     * 
     * @param value
     *     allowed object is
     *     {@link String }
     *     
     */
    public void setFUELCODE(String value) {
        this.fuelcode = value;
    }

    /**
     * Obtient la valeur de la propriété blendperc.
     * 
     * @return
     *     possible object is
     *     {@link QUANTITY }
     *     
     */
    public QUANTITY getBLENDPERC() {
        return blendperc;
    }

    /**
     * Définit la valeur de la propriété blendperc.
     * 
     * @param value
     *     allowed object is
     *     {@link QUANTITY }
     *     
     */
    public void setBLENDPERC(QUANTITY value) {
        this.blendperc = value;
    }

}

==> eam-wshub-proxyclient-12.0-sources.jar: net/datastream/schemas/mp_fields/FUELBLEND_Type.java <==

package net.datastream.schemas.mp_fields;

import javax.xml.bind.annotation.XmlAccessType;
import javax.xml.bind.annotation.XmlAccessorType;
import javax.xml.bind.annotation.XmlElement;
import javax.xml.bind.annotation.XmlType;
import org.openapplications.oagis_segments.QUANTITY;


/**
 * <p>Java class for FUELBLEND_Type complex type.
 * 
 * <p>The following schema fragment specifies the expected content contained within this class.
 * 
 * <pre>
 * &lt;complexType name="FUELBLEND_Type">
 *   &lt;complexContent>
 *     &lt;restriction base="{http://www.w3.org/2001/XMLSchema}anyType">
 *       &lt;sequence>
 *         &lt;element ref="{http://schemas.datastream.net/MP_fields}FUELCODE"/>
 *         &lt;element ref="{http://schemas.datastream.net/MP_fields}BLENDPERC"/>
 *       &lt;/sequence>
 *     &lt;/restriction>
 *   &lt;/complexContent>
 * &lt;/complexType>
 * </pre>
 * 
 * 
 */
@XmlAccessorType(XmlAccessType.FIELD)
@XmlType(name = "FUELBLEND_Type", propOrder = {
    "fuelcode",
    "blendperc"
})
public class FUELBLEND_Type {

    @XmlElement(name = "FUELCODE", required = true)
    protected String fuelcode;
    @XmlElement(name = "BLENDPERC", required = true)
    protected QUANTITY blendperc;

    /**
     * Gets the value of the fuelcode property.
     * 
     * @return
     *     possible object is
     *     {@link String }
     *     
     */
    public String getFUELCODE() {
        return fuelcode;
    }

    /**
     * Sets the value of the fuelcode property.
     * 
     * @param value
     *     allowed object is
     *     {@link String }
     *     
     */
    public void setFUELCODE(String value) {
        this.fuelcode = value;
    }

    /**
     * Gets the value of the blendperc property.
     * 
     * @return
     *     possible object is
     *     {@link QUANTITY }
     *     
     */
    public QUANTITY getBLENDPERC() {
        return blendperc;
    }

    /**
     * Sets the value of the blendperc property.
     * 
     * @param value
     *     allowed object is
     *     {@link QUANTITY }
     *     
     */
    public void setBLENDPERC(QUANTITY value) {
        this.blendperc = value;
    }

}
